@@ -1,5 +1,4 @@
 from django.conf import settings
-from django.core.management import call_command
 
 
 def pytest_configure():
@@ -11,7 +10,7 @@ def pytest_configure():
         DATABASES={
             'default': {
                 'ENGINE': 'django.db.backends.sqlite3',
-                'NAME': 'test'
+                'NAME': 'test_db'
             }
         },
 
@@ -24,11 +23,3 @@ def pytest_configure():
             'tests',
         ]
     )
-
-    try:
-        from django import setup
-    except ImportError:
-        call_command('syncdb', interactive=False)
-    else:
-        setup()
-        call_command('migrate')
