@@ -1,8 +1,10 @@
+from django.test import TestCase
+
 from rest_assured.testcases import DetailAPITestCaseMixin
 from tests import mocks
 
 
-class TestDetailTestCase:
+class TestDetailTestCase(TestCase):
     def get_case(self, **kwargs):
         class MockDetailTestCase(DetailAPITestCaseMixin, mocks.MockTestCase):
             base_name = 'stuff'
@@ -27,3 +29,10 @@ class TestDetailTestCase:
         instance.setUp()
         response = instance.test_detail()
         assert response
+
+    def test_test_detail_callable_attribute(self):
+        instance = self.get_case(methodName='dummy')
+        instance.attributes_to_check = ['name', ('answer', lambda o: o.answer)]
+        instance.setUp()
+        response = instance.test_detail()
+        assert response
